@@ -10,7 +10,7 @@ import imagesize
 
 from .cover_page_ams import create_cover_page
 from .cover_page_project import create_project_cover
-from .testdir import listdirs
+from .directory import get_images
 
 font_dir = Path('X:/9999_BID_AMS/AMS-VFB_Fonts')
 
@@ -24,11 +24,11 @@ def get_cwd():
     cwd = os.getcwd()
     if cwd[0] != 'X':
         click.secho("Please run the tool in the X:/ drive")
-        return
+        return None
 
     if len(cwd) == 3:
         click.secho('Please run tool inside a project folder')
-        return
+        return None
 
     return cwd
 
@@ -47,9 +47,12 @@ def main():
 
     project_path = Path(get_cwd())
 
+    if project_path is None:
+        return
+
     click.echo(f"🕵️‍♀️ We're running in {str(project_path)}")
 
-    selection = listdirs(project_path)
+    selection = get_images(project_path)
 
     project_name = input("🙏 Type in the project name: ")
 
